# smax
Just a small wrapper to website scraping utilities.

It just wraps around `requests`, `bs4` and `cloudscraper`.

## Install
```
pip3 install smaxpy
```


## Usage
```python
from smaxpy import Smax

a = Smax()

print(a.title)
```

## 
### &copy; 2021 TheBoringDude